@@ -13,6 +13,11 @@
 #include "ntp_stdlib.h"
 #include "ntp_assert.h"
 
+/* This is a glibc thing, not standardized */
+#ifndef NI_MAXSERV
+#define NI_MAXSERV 32
+#endif
+
 /*
  * decodenetnum		convert text IP address and port to sockaddr_u
  *
@@ -26,8 +31,11 @@
  * [IPv6]:port
  *
  * The IP must be numeric but the port can be symbolic.
+ *
+ * return: 0 for success
+ *         negative numbers for error codes
  */
-bool
+int
 decodenetnum(
 	const char *num,
 	sockaddr_u *netnum
@@ -35,16 +43,22 @@ decodenetnum(
 {
 	struct addrinfo hints, *ai = NULL;
 	const char *ip_start, *ip_end, *port_start, *temp;
-	const size_t numlen = strlen(num);
+	size_t numlen;
 	bool have_brackets;
+        int retcode = 0;
 
 	char ip[INET6_ADDRSTRLEN];
 
-	NTP_REQUIRE(num != NULL);
+	ZERO(*netnum);               /* don't return random data on fail */
+        /* check num not NULL before using it */
+	if ( NULL == num) {
+                return -4001;
+        }
+	numlen = strlen(num);
 	/* Quickly reject empty or impossibly long inputs. */
 	if(numlen == 0 ||
-	   numlen > (sizeof ip - 1) + (NI_MAXSERV - 1) + (3 /* "[]:" */)) {
-		return false;
+	   numlen > ((sizeof(ip) - 1) + (NI_MAXSERV - 1) + (3 /* "[]:" */))) {
+		return -4002;
 	}
 
 	/* Is this a bracketed IPv6 address? */
@@ -65,7 +79,7 @@ decodenetnum(
 		}
 		else {
 			/* Anything else must be invalid. */
-			return false;
+			return -4003;
 		}
 	}
 	/* No brackets. Searching backward, see if there's at least one
@@ -98,8 +112,8 @@ decodenetnum(
 	   either NULL or pointing to the start of the port. Check
 	   whether the IP is short enough to possibly be valid and
 	   if so copy it into ip. */
-	if(ip_end - ip_start + 1 > (int)sizeof(ip)) {
-		return false;
+	if ((ip_end - ip_start + 1) > (int)sizeof(ip)) {
+		return -4004;
 	} else {
 		memcpy(ip, ip_start, (size_t)(ip_end - ip_start));
 		ip[ip_end - ip_start] = '\0';
@@ -117,16 +131,16 @@ decodenetnum(
 	   either the IP address or the port is well-formed, but at
 	   least they're unambiguously delimited from each other.
 	   Let getaddrinfo() perform all further validation. */
-	if(getaddrinfo(ip, port_start == NULL ? "ntp" : port_start,
-		       &hints, &ai) != 0) {
-		return false;
+	retcode = getaddrinfo(ip, port_start == NULL ? "ntp" : port_start,
+		       &hints, &ai);
+	if(retcode) {
+		return retcode;
 	}
 
-	NTP_INSIST(ai->ai_addrlen <= sizeof(*netnum));
+	INSIST(ai->ai_addrlen <= sizeof(*netnum));
 	if(netnum) {
-		ZERO(*netnum);
 		memcpy(netnum, ai->ai_addr, ai->ai_addrlen);
 	}
 	freeaddrinfo(ai);
-	return true;
+	return 0;
 }
