@@ -917,15 +917,14 @@ ntpdmain(
  */
 static void mainloop(void)
 {
-	struct recvbuf *rbuf;
-
 	init_timer();
 
 	for (;;) {
 		if (sig_flags.sawQuit)
 			finish_safe(signo);
 
-		if (!sig_flags.sawALRM && !has_full_recv_buffer()) {
+		if (!sig_flags.sawALRM) {
+			// FIXME: Check other flags
 			/*
 			 * Nothing to do.  Wait for something.
 			 */
@@ -948,56 +947,6 @@ static void mainloop(void)
 		}
 #endif
 
-# ifdef ENABLE_DEBUG_TIMING
-		{
-			l_fp pts;
-			l_fp tsa, tsb;
-			int bufcount = 0;
-
-			get_systime(&pts);
-			tsa = pts;
-# endif
-			rbuf = get_full_recv_buffer();
-			while (rbuf != NULL) {
-
-				if (sig_flags.sawALRM) {
-					/* avoid timer starvation during lengthy I/O handling */
-					timer();
-					sig_flags.sawALRM = false;
-				}
-
-				/*
-				 * Call the data procedure to handle each received
-				 * packet.
-				 */
-				if (rbuf->receiver != NULL) {
-# ifdef ENABLE_DEBUG_TIMING
-					l_fp dts = pts;
-
-					dts -= rbuf->recv_time;
-					DPRINT(2, ("processing timestamp delta %s (with prec. fuzz)\n", lfptoa(dts, 9)));
-					collect_timing(rbuf, "buffer processing delay", 1, dts);
-					bufcount++;
-# endif
-					(*rbuf->receiver)(rbuf);
-				} else {
-					msyslog(LOG_ERR, "ERR: fatal: receive buffer callback NULL");
-					abort();
-				}
-
-				freerecvbuf(rbuf);
-				rbuf = get_full_recv_buffer();
-			}
-# ifdef ENABLE_DEBUG_TIMING
-			get_systime(&tsb);
-			tsb -= tsa;
-			if (bufcount) {
-				collect_timing(NULL, "processing", bufcount, tsb);
-				DPRINT(2, ("processing time for %d buffers %s\n", bufcount, lfptoa(tsb, 9)));
-			}
-		}
-# endif
-
 		/*
 		 * Check files
 		 */
