@@ -595,8 +595,11 @@ gpsd_shutdown(
 	if (up == NULL)
 		return;
 
-	/* now check if we must close IO resources */
-	if (pp != up->pps_peer->procptr) {
+	if (up->pps_peer == NULL) {
+		/* This is NULL if no related PPS */
+		DPRINT(1, ("%s: pps_peer found NULL", up->logname));
+	} else if (pp != up->pps_peer->procptr) {
+		/* now check if we must close IO resources */
 		if (-1 != pp->io.fd) {
 			DPRINT(1, ("%s: closing clock, fd=%d\n",
 				   up->logname, pp->io.fd));
