@@ -100,7 +100,7 @@ local_start(
 	/*
 	 * Initialize miscellaneous variables
 	 */
-	peer->precision = sys_precision;
+	peer->precision = sys_vars.sys_precision;
 	pp->leap = LEAP_NOTINSYNC;
 	peer->stratum = STRATUM;
 	pp->stratum = STRATUM;
@@ -138,7 +138,7 @@ local_poll(
 	/*
 	 * Do no evil unless the house is dark or lit with our own lamp.
 	 */
-	if (!(sys_peer == NULL || sys_peer == peer))
+	if (!(sys_vars.sys_peer == NULL || sys_vars.sys_peer == peer))
 		return;
 
 	pp = peer->procptr;
