@@ -19,6 +19,14 @@ TEST_TEAR_DOWN(prettydate) {}
 
 static const uint32_t HALF = 2147483648UL;
 
+TEST(prettydate, Rfc3339Date1) {
+    TEST_ASSERT_EQUAL_STRING("2036-02-07T06:28:16.000Z", rfc3339date(0));
+}
+
+TEST(prettydate, Rfc3339Time1) {
+    TEST_ASSERT_EQUAL_STRING("2036-02-07T06:28:16.000Z", rfc3339date(0));
+}
+
 TEST(prettydate, ConstantDate) {
     l_fp t = lfpinit((int32_t)3485080800LL, HALF); // 2010-06-09 14:00:00.5
 
@@ -27,4 +35,6 @@ TEST(prettydate, ConstantDate) {
 
 TEST_GROUP_RUNNER(prettydate) {
 	RUN_TEST_CASE(prettydate, ConstantDate);
+	RUN_TEST_CASE(prettydate, Rfc3339Date1);
+	RUN_TEST_CASE(prettydate, Rfc3339Time1);
 }
